@@ -8,9 +8,6 @@
 # granted to it by virtue of its status as an Intergovernmental Organization  #
 # or submit itself to any jurisdiction.                                       #
 ###############################################################################
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
 
 from collections import defaultdict
 import sys
@@ -20,7 +17,6 @@ import json
 import zlib
 
 import cachetools
-import tornado
 from tornado.escape import json_decode, json_encode
 
 from DIRAC import gConfig, gLogger
@@ -29,9 +25,7 @@ from DIRAC.Core.Workflow.Workflow import fromXMLString as workflowFromXMLString
 from DIRAC.DataManagementSystem.Client.DataManager import DataManager
 from DIRAC.Resources.Storage.StorageElement import StorageElement
 from DIRAC.TransformationSystem.Client.TransformationClient import TransformationClient
-from LHCbDIRAC.BookkeepingSystem.Client.BKQuery import makeBKPath
 from LHCbDIRAC.BookkeepingSystem.Client.BookkeepingClient import BookkeepingClient
-from LHCbDIRAC.Core.Utilities.ProductionData import getLogPath
 from LHCbDIRAC.ProductionManagementSystem.Client.ProductionRequestClient import ProductionRequestClient
 from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr, asyncGen
 
@@ -86,7 +80,7 @@ class AnalysisProductionsHandler(WebHandler):
         if not requestIDs:
             self.set_status(400)
             return self.finish(json_encode("Invalid value of requestIDs"))
-        requestIDs = json_decode(requestIDs[0])
+        requestIDs = json_decode(requestIDs)
         if not requestIDs:
             return self.finish(json_encode([]))
 
@@ -97,7 +91,7 @@ class AnalysisProductionsHandler(WebHandler):
 
         # Get the requested productions
         productions = getProductions({"RequestID": ",".join(map(str, requestIDs))})
-        if set(requestIDs) != set(p["RequestID"] for p in productions):
+        if set(requestIDs) != {p["RequestID"] for p in productions}:
             self.set_status(400)
             return self.finish(json_encode("Invalid request IDs passed"))
 
@@ -351,15 +345,15 @@ def productionToDict(production, transformations):
     outputPattern = ""
     if pfnsAtCERN:
         # Get the file extension
-        extensions = set(os.path.splitext(p)[1] for p in pfnsAtCERN)
+        extensions = {os.path.splitext(p)[1] for p in pfnsAtCERN}
         if len(extensions) > 1:
             raise NotImplementedError(extensions)
         suffix = "*" + extensions.pop()
 
         # Find a common directory
-        pfnDirectories = set(os.path.dirname(p) for p in pfnsAtCERN)
+        pfnDirectories = {os.path.dirname(p) for p in pfnsAtCERN}
         if len(pfnDirectories) > 1:
-            pfnDirectories = set(os.path.dirname(p) for p in pfnsAtCERN)
+            pfnDirectories = {os.path.dirname(p) for p in pfnsAtCERN}
             if len(pfnDirectories) > 1:
                 # This only goes two levels deep by convention
                 raise NotImplementedError(pfnDirectories)
