@@ -67,7 +67,10 @@ class BookkeepingBrowserHandler(WebHandler):
                 node["method"] = i["method"] if "method" in i else ""
                 node["cls"] = "folder" if i["expandable"] else "file"
                 if "level" in i and i["level"] == "Event types":
-                    node["text"] = "%s (%s)" % (i["name"], i["Description"])
+                    if "Description" in i:
+                        node["text"] = f"{i['name']} ({i['Description']})"
+                    else:
+                        node["text"] = i["name"]
                 if "level" in i and i["level"] == "FileTypes":
                     node["leaf"] = True
                 else:
@@ -570,7 +573,7 @@ class BookkeepingBrowserHandler(WebHandler):
             return
 
         tmpdir = tempfile.mkdtemp(prefix=userName)
-        catalog = "%s/%s.xml" % (tmpdir, fileName)
+        catalog = f"{tmpdir}/{fileName}.xml"
         retVal = yield self.threadTask(DiracLHCb().getInputDataCatalog, list(lfns), siteName, catalog, True)
         if not retVal["OK"]:
             raise WErr.fromSERROR(retVal)
@@ -581,7 +584,7 @@ class BookkeepingBrowserHandler(WebHandler):
             exists[lfn] = lfns[lfn]
 
         if not fileName.endswith(".py"):
-            fileName = "%s/%s.py" % (tmpdir, fileName)
+            fileName = f"{tmpdir}/{fileName}.py"
 
         kwargs = dict(catalog=catalog, dataset=bkQuery)
         if formatType.lower() == "pfn":
