@@ -25,7 +25,7 @@ class LHCbJobMonitorHandler(JobMonitorHandler):
         self.render("JobMonitor/standalone.tpl", config_data=json.dumps(SessionData(None, None).getData()))
 
     def _request(self):
-        req = super(LHCbJobMonitorHandler, self)._request()
+        req = super()._request()
         runs = list(json.loads(self.get_argument("RunNumbers", "[]")))
         if runs:
             req["runNumber"] = runs
