@@ -13,8 +13,6 @@
 import json
 import datetime
 import tornado
-from six import text_type
-import six
 
 from WebAppDIRAC.Lib.WebHandler import WebHandler, WErr, asyncGen
 
@@ -154,7 +152,7 @@ class ProductionRequestManagerHandler(WebHandler):
     def __unescape(self, d):
         """Unescape HTML code in parameters"""
         for x in d:
-            d[x] = text_type(d[x][-1])
+            d[x] = str(d[x][-1])
             s = d[x].replace("&amp;", "&")
             while s != d[x]:
                 d[x] = s
@@ -235,7 +233,7 @@ class ProductionRequestManagerHandler(WebHandler):
                 result[x] = req[y]
         result["_is_leaf"] = not result["_is_leaf"]
         if req["bkTotal"] is not None and req["rqTotal"] is not None and req["rqTotal"]:
-            result["progress"] = int(req["bkTotal"]) * 100 / int(req["rqTotal"])
+            result["progress"] = f"{int(req['bkTotal']) / int(req['rqTotal']):.2%}"
         else:
             result["progress"] = None
         if req["SimCondDetail"]:
@@ -331,7 +329,7 @@ class ProductionRequestManagerHandler(WebHandler):
         nm = [x for x in cond if x not in tr]
         if nm:
             return S_ERROR("Unmached run conditions: %s" % str(nm))
-        v = dict([(tr[x], cond[x]) for x in cond])
+        v = {tr[x]: cond[x] for x in cond}
         v["condType"] = rType
         if rType == "Run":
             v["DetectorCond"] = self.__runDetectorCond(v)
@@ -502,7 +500,7 @@ class ProductionRequestManagerHandler(WebHandler):
             return
         rows = []
         for et in result["Value"]:
-            rows.append({"id": et[0], "name": et[1], "text": "%s - %s" % (str(et[0]), str(et[1]))})
+            rows.append({"id": et[0], "name": et[1], "text": f"{str(et[0])} - {str(et[1])}"})
         rows.sort(key=lambda x: x["id"])
         if addempty:
             rows.insert(0, {"id": 99999999, "name": "", "text": "&nbsp;"})
@@ -650,7 +648,7 @@ class ProductionRequestManagerHandler(WebHandler):
                     scd = result["Value"]
                 x.update(scd)
             if x["text"] in known:
-                gLogger.error("Duplicated entry: %s %s" % (str(known[x["text"]]), str(x)))
+                gLogger.error("Duplicated entry:", f"{known[x['text']]} {x}")
             else:
                 known[x["text"]] = x
                 value.append(x)
@@ -659,7 +657,7 @@ class ProductionRequestManagerHandler(WebHandler):
 
     @asyncGen
     def web_save(self):
-        rdict = {k: self.get_arguments(k) for k in self.request.arguments}
+        rdict = {k: self.get_arguments(k, strip=False) for k in self.request.arguments}
         self.__unescape(rdict)
 
         # Make it backward compatible
