@@ -17,29 +17,14 @@ if six.PY2:
 
 
 # Define Version
-if six.PY3:
-    from pkg_resources import get_distribution, DistributionNotFound
+from pkg_resources import get_distribution, DistributionNotFound
 
-    try:
-        __version__ = get_distribution(__name__).version
-        version = __version__
-    except DistributionNotFound:
-        # package is not installed
-        version = "Unknown"
-else:
-    majorVersion = 5
-    minorVersion = 3
-    patchLevel = 1
-    preVersion = 0
-
-    version = "v%sr%s" % (majorVersion, minorVersion)
-    buildVersion = "v%dr%d" % (majorVersion, minorVersion)
-    if patchLevel:
-        version = "%sp%s" % (version, patchLevel)
-        buildVersion = "%s build %s" % (buildVersion, patchLevel)
-    if preVersion:
-        version = "%s-pre%s" % (version, preVersion)
-        buildVersion = "%s pre %s" % (buildVersion, preVersion)
+try:
+    __version__ = get_distribution(__name__).version
+    version = __version__
+except DistributionNotFound:
+    # package is not installed
+    version = "Unknown"
 
 
 def extension_metadata():
